# Generated by h2py from /usr/include/netinet/in.h

# Included from sys/cdefs.h

# Included from machine/cdefs.h
def __P(protos): return protos		 

def __STRING(x): return #x

def __P(protos): return ()		 

def __STRING(x): return "x"

def __attribute__(x): return  

def __bounded(args): return  

def __predict_true(exp): return __builtin_expect(((exp) != 0), 1)

def __predict_false(exp): return __builtin_expect(((exp) != 0), 0)

def __predict_true(exp): return ((exp) != 0)

def __predict_false(exp): return ((exp) != 0)

def __aligned(x): return __attribute__((__aligned__(x)))

__XPG_VISIBLE = 800
_POSIX_C_SOURCE = 202405L
__XPG_VISIBLE = 700
_POSIX_C_SOURCE = 200809L
__XPG_VISIBLE = 600
_POSIX_C_SOURCE = 200112L
__XPG_VISIBLE = 520
_POSIX_C_SOURCE = 199506L
__XPG_VISIBLE = 500
_POSIX_C_SOURCE = 199506L
__XPG_VISIBLE = 420
__XPG_VISIBLE = 400
__XPG_VISIBLE = 300
__POSIX_VISIBLE = 202405
__ISO_C_VISIBLE = 2017
__POSIX_VISIBLE = 200809
__ISO_C_VISIBLE = 1999
__POSIX_VISIBLE = 200112
__ISO_C_VISIBLE = 1999
__POSIX_VISIBLE = 199506
__ISO_C_VISIBLE = 1990
__POSIX_VISIBLE = 199309
__ISO_C_VISIBLE = 1990
__POSIX_VISIBLE = 199209
__ISO_C_VISIBLE = 1990
__POSIX_VISIBLE = 199009
__ISO_C_VISIBLE = 1990
__POSIX_VISIBLE = 198808
__ISO_C_VISIBLE = 0
__POSIX_VISIBLE = 0
__XPG_VISIBLE = 0
__ISO_C_VISIBLE = 1990
__ISO_C_VISIBLE = 2011
__ISO_C_VISIBLE = 1999
__BSD_VISIBLE = 0
__XPG_VISIBLE = 800
__POSIX_VISIBLE = 202405
__ISO_C_VISIBLE = 2017
__BSD_VISIBLE = 1

# Included from sys/types.h

# Included from sys/endian.h

# Included from sys/_endian.h

# Included from sys/_types.h

# Included from machine/_types.h
_STACKALIGNBYTES = 15
_MAX_PAGE_SHIFT = 12

# Included from machine/endian.h
_LITTLE_ENDIAN = 1234
_BIG_ENDIAN = 4321
_PDP_ENDIAN = 3412
def __swap16gen(x): return \

def __swap32gen(x): return \

def __swap64gen(x): return \

def __swap16(x): return \

def __swap32(x): return \

def __swap64(x): return \

_QUAD_HIGHWORD = 1
_QUAD_LOWWORD = 0
__htobe16 = __swap16
__htobe32 = __swap32
__htobe64 = __swap64
def __htole16(x): return ((__uint16_t)(x))

def __htole32(x): return ((__uint32_t)(x))

def __htole64(x): return ((__uint64_t)(x))

def __bemtoh16(_x): return __mswap16(_x)

def __bemtoh32(_x): return __mswap32(_x)

def __bemtoh64(_x): return __mswap64(_x)

_QUAD_HIGHWORD = 0
_QUAD_LOWWORD = 1
def __htobe16(x): return ((__uint16_t)(x))

def __htobe32(x): return ((__uint32_t)(x))

def __htobe64(x): return ((__uint64_t)(x))

__htole16 = __swap16
__htole32 = __swap32
__htole64 = __swap64
def __lemtoh16(_x): return __mswap16(_x)

def __lemtoh32(_x): return __mswap32(_x)

def __lemtoh64(_x): return __mswap64(_x)

LITTLE_ENDIAN = _LITTLE_ENDIAN
BIG_ENDIAN = _BIG_ENDIAN
PDP_ENDIAN = _PDP_ENDIAN
def htobe16(x): return __htobe16(x)

def htobe32(x): return __htobe32(x)

def htobe64(x): return __htobe64(x)

def htole16(x): return __htole16(x)

def htole32(x): return __htole32(x)

def htole64(x): return __htole64(x)

def be16toh(x): return __htobe16(x)

def be32toh(x): return __htobe32(x)

def be64toh(x): return __htobe64(x)

def le16toh(x): return __htole16(x)

def le32toh(x): return __htole32(x)

def le64toh(x): return __htole64(x)

def swap16(x): return __swap16(x)

def swap32(x): return __swap32(x)

def swap64(x): return __swap64(x)

def betoh16(x): return __htobe16(x)

def betoh32(x): return __htobe32(x)

def betoh64(x): return __htobe64(x)

def letoh16(x): return __htole16(x)

def letoh32(x): return __htole32(x)

def letoh64(x): return __htole64(x)

def htons(x): return __htobe16(x)

def htonl(x): return __htobe32(x)

def ntohs(x): return __htobe16(x)

def ntohl(x): return __htobe32(x)

bemtoh16 = __bemtoh16
bemtoh32 = __bemtoh32
bemtoh64 = __bemtoh64
lemtoh16 = __lemtoh16
lemtoh32 = __lemtoh32
lemtoh64 = __lemtoh64
def major(x): return (((unsigned)(x) >> 8) & 0xff)

def minor(x): return ((unsigned)((x) & 0xff) | (((x) & (-65536)) >> 8))

false = 0
true = 1
false = false
true = true
__bool_true_false_are_defined = 1
def htons(x): return __htobe16(x)

def htonl(x): return __htobe32(x)

def ntohs(x): return __htobe16(x)

def ntohl(x): return __htobe32(x)

IPPROTO_IP = 0
IPPROTO_HOPOPTS = IPPROTO_IP
IPPROTO_ICMP = 1
IPPROTO_IGMP = 2
IPPROTO_GGP = 3
IPPROTO_IPIP = 4
IPPROTO_IPV4 = IPPROTO_IPIP
IPPROTO_TCP = 6
IPPROTO_EGP = 8
IPPROTO_PUP = 12
IPPROTO_UDP = 17
IPPROTO_IDP = 22
IPPROTO_TP = 29
IPPROTO_IPV6 = 41
IPPROTO_ROUTING = 43
IPPROTO_FRAGMENT = 44
IPPROTO_RSVP = 46
IPPROTO_GRE = 47
IPPROTO_ESP = 50
IPPROTO_AH = 51
IPPROTO_MOBILE = 55
IPPROTO_ICMPV6 = 58
IPPROTO_NONE = 59
IPPROTO_DSTOPTS = 60
IPPROTO_EON = 80
IPPROTO_ETHERIP = 97
IPPROTO_ENCAP = 98
IPPROTO_PIM = 103
IPPROTO_IPCOMP = 108
IPPROTO_CARP = 112
IPPROTO_SCTP = 132
IPPROTO_UDPLITE = 136
IPPROTO_MPLS = 137
IPPROTO_PFSYNC = 240
IPPROTO_RAW = 255
IPPROTO_MAX = 256
IPPROTO_DIVERT = 258
IPPORT_RESERVED = 1024
IPPORT_USERRESERVED = 49151
IPPORT_HIFIRSTAUTO = 49152
IPPORT_HILASTAUTO = 65535
IPPROTO_DONE = 257
def __IPADDR(x): return ((u_int32_t)(x))

IN_CLASSA_NSHIFT = 24
IN_CLASSA_MAX = 128
IN_CLASSB_NSHIFT = 16
IN_CLASSB_MAX = 65536
IN_CLASSC_NSHIFT = 8
IN_CLASSD_NSHIFT = 28
def IN_MULTICAST(i): return IN_CLASSD(i)

IN_RFC3021_NSHIFT = 31
IN_LOOPBACKNET = 127
IP_OPTIONS = 1
IP_HDRINCL = 2
IP_TOS = 3
IP_TTL = 4
IP_RECVOPTS = 5
IP_RECVRETOPTS = 6
IP_RECVDSTADDR = 7
IP_RETOPTS = 8
IP_MULTICAST_IF = 9
IP_MULTICAST_TTL = 10
IP_MULTICAST_LOOP = 11
IP_ADD_MEMBERSHIP = 12
IP_DROP_MEMBERSHIP = 13
IP_PORTRANGE = 19
IP_AUTH_LEVEL = 20
IP_ESP_TRANS_LEVEL = 21
IP_ESP_NETWORK_LEVEL = 22
IP_IPSEC_LOCAL_ID = 23
IP_IPSEC_REMOTE_ID = 24
IP_IPSEC_LOCAL_CRED = 25
IP_IPSEC_REMOTE_CRED = 26
IP_IPSEC_LOCAL_AUTH = 27
IP_IPSEC_REMOTE_AUTH = 28
IP_IPCOMP_LEVEL = 29
IP_RECVIF = 30
IP_RECVTTL = 31
IP_MINTTL = 32
IP_RECVDSTPORT = 33
IP_PIPEX = 34
IP_RECVRTABLE = 35
IP_IPSECFLOWINFO = 36
IP_IPDEFTTL = 37
IP_SENDSRCADDR = IP_RECVDSTADDR
IP_RTABLE = 0x1021
IPSEC_LEVEL_BYPASS = 0x00
IPSEC_LEVEL_NONE = 0x00
IPSEC_LEVEL_AVAIL = 0x01
IPSEC_LEVEL_USE = 0x02
IPSEC_LEVEL_REQUIRE = 0x03
IPSEC_LEVEL_UNIQUE = 0x04
IPSEC_LEVEL_DEFAULT = IPSEC_LEVEL_AVAIL
IPSEC_AUTH_LEVEL_DEFAULT = IPSEC_LEVEL_DEFAULT
IPSEC_ESP_TRANS_LEVEL_DEFAULT = IPSEC_LEVEL_DEFAULT
IPSEC_ESP_NETWORK_LEVEL_DEFAULT = IPSEC_LEVEL_DEFAULT
IPSEC_IPCOMP_LEVEL_DEFAULT = IPSEC_LEVEL_DEFAULT
IP_DEFAULT_MULTICAST_TTL = 1
IP_DEFAULT_MULTICAST_LOOP = 1
IP_MIN_MEMBERSHIPS = 15
IP_MAX_MEMBERSHIPS = 4095
IP_PORTRANGE_DEFAULT = 0
IP_PORTRANGE_HIGH = 1
IP_PORTRANGE_LOW = 2
INET_ADDRSTRLEN = 16
IPPROTO_MAXID = (IPPROTO_DIVERT + 1)
IPCTL_FORWARDING = 1
IPCTL_SENDREDIRECTS = 2
IPCTL_DEFTTL = 3
IPCTL_SOURCEROUTE = 5
IPCTL_DIRECTEDBCAST = 6
IPCTL_IPPORT_FIRSTAUTO = 7
IPCTL_IPPORT_LASTAUTO = 8
IPCTL_IPPORT_HIFIRSTAUTO = 9
IPCTL_IPPORT_HILASTAUTO = 10
IPCTL_IPPORT_MAXQUEUE = 11
IPCTL_ENCDEBUG = 12
IPCTL_IPSEC_STATS = 13
IPCTL_IPSEC_EXPIRE_ACQUIRE = 14
IPCTL_IPSEC_EMBRYONIC_SA_TIMEOUT = 15
IPCTL_IPSEC_REQUIRE_PFS = 16
IPCTL_IPSEC_SOFT_ALLOCATIONS = 17
IPCTL_IPSEC_ALLOCATIONS = 18
IPCTL_IPSEC_SOFT_BYTES = 19
IPCTL_IPSEC_BYTES = 20
IPCTL_IPSEC_TIMEOUT = 21
IPCTL_IPSEC_SOFT_TIMEOUT = 22
IPCTL_IPSEC_SOFT_FIRSTUSE = 23
IPCTL_IPSEC_FIRSTUSE = 24
IPCTL_IPSEC_ENC_ALGORITHM = 25
IPCTL_IPSEC_AUTH_ALGORITHM = 26
IPCTL_MTUDISC = 27
IPCTL_MTUDISCTIMEOUT = 28
IPCTL_IPSEC_IPCOMP_ALGORITHM = 29
IPCTL_IFQUEUE = 30
IPCTL_MFORWARDING = 31
IPCTL_MULTIPATH = 32
IPCTL_STATS = 33
IPCTL_MRTPROTO = 34
IPCTL_MRTSTATS = 35
IPCTL_ARPQUEUED = 36
IPCTL_MRTMFC = 37
IPCTL_MRTVIF = 38
IPCTL_ARPTIMEOUT = 39
IPCTL_ARPDOWN = 40
IPCTL_ARPQUEUE = 41
IPCTL_MAXID = 42

# Included from netinet6/in6.h
INET6_ADDRSTRLEN = 46
def IN6_IS_ADDR_UNSPECIFIED(a): return \

def IN6_IS_ADDR_LOOPBACK(a): return \

def IN6_IS_ADDR_V4COMPAT(a): return \

def IN6_IS_ADDR_V4MAPPED(a): return \

def IN6_IS_ADDR_LINKLOCAL(a): return \

def IN6_IS_ADDR_SITELOCAL(a): return \

__IPV6_ADDR_SCOPE_NODELOCAL = 0x01
__IPV6_ADDR_SCOPE_INTFACELOCAL = 0x01
__IPV6_ADDR_SCOPE_LINKLOCAL = 0x02
__IPV6_ADDR_SCOPE_SITELOCAL = 0x05
__IPV6_ADDR_SCOPE_ORGLOCAL = 0x08
__IPV6_ADDR_SCOPE_GLOBAL = 0x0e
def IN6_IS_ADDR_MC_NODELOCAL(a): return \

def IN6_IS_ADDR_MC_INTFACELOCAL(a): return \

def IN6_IS_ADDR_MC_LINKLOCAL(a): return \

def IN6_IS_ADDR_MC_SITELOCAL(a): return \

def IN6_IS_ADDR_MC_ORGLOCAL(a): return \

def IN6_IS_ADDR_MC_GLOBAL(a): return \

def IN6_IS_SCOPE_LINKLOCAL(a): return \

def IN6_IS_SCOPE_EMBED(a): return \

def IFA6_IS_DEPRECATED(a): return \

def IFA6_IS_INVALID(a): return \

IPV6_UNICAST_HOPS = 4
IPV6_MULTICAST_IF = 9
IPV6_MULTICAST_HOPS = 10
IPV6_MULTICAST_LOOP = 11
IPV6_JOIN_GROUP = 12
IPV6_LEAVE_GROUP = 13
IPV6_PORTRANGE = 14
ICMP6_FILTER = 18
IPV6_CHECKSUM = 26
IPV6_V6ONLY = 27
IPV6_RTHDRDSTOPTS = 35
IPV6_RECVPKTINFO = 36
IPV6_RECVHOPLIMIT = 37
IPV6_RECVRTHDR = 38
IPV6_RECVHOPOPTS = 39
IPV6_RECVDSTOPTS = 40
IPV6_USE_MIN_MTU = 42
IPV6_RECVPATHMTU = 43
IPV6_PATHMTU = 44
IPV6_PKTINFO = 46
IPV6_HOPLIMIT = 47
IPV6_NEXTHOP = 48
IPV6_HOPOPTS = 49
IPV6_DSTOPTS = 50
IPV6_RTHDR = 51
IPV6_AUTH_LEVEL = 53
IPV6_ESP_TRANS_LEVEL = 54
IPV6_ESP_NETWORK_LEVEL = 55
IPSEC6_OUTSA = 56
IPV6_RECVTCLASS = 57
IPV6_AUTOFLOWLABEL = 59
IPV6_IPCOMP_LEVEL = 60
IPV6_TCLASS = 61
IPV6_DONTFRAG = 62
IPV6_PIPEX = 63
IPV6_RECVDSTPORT = 64
IPV6_MINHOPCOUNT = 65
IPV6_RTABLE = 0x1021
IPV6_RTHDR_LOOSE = 0
IPV6_RTHDR_TYPE_0 = 0
IPV6_DEFAULT_MULTICAST_HOPS = 1
IPV6_DEFAULT_MULTICAST_LOOP = 1
IPV6_PORTRANGE_DEFAULT = 0
IPV6_PORTRANGE_HIGH = 1
IPV6_PORTRANGE_LOW = 2
IPV6PROTO_MAXID = (IPPROTO_DIVERT + 1)
IPV6CTL_FORWARDING = 1
IPV6CTL_SENDREDIRECTS = 2
IPV6CTL_DEFHLIM = 3
IPV6CTL_FORWSRCRT = 5
IPV6CTL_STATS = 6
IPV6CTL_MRTSTATS = 7
IPV6CTL_MRTPROTO = 8
IPV6CTL_MAXFRAGPACKETS = 9
IPV6CTL_SOURCECHECK = 10
IPV6CTL_SOURCECHECK_LOGINT = 11
IPV6CTL_ACCEPT_RTADV = 12
IPV6CTL_LOG_INTERVAL = 14
IPV6CTL_HDRNESTLIMIT = 15
IPV6CTL_DAD_COUNT = 16
IPV6CTL_AUTO_FLOWLABEL = 17
IPV6CTL_DEFMCASTHLIM = 18
IPV6CTL_MAXFRAGS = 41
IPV6CTL_MFORWARDING = 42
IPV6CTL_MULTIPATH = 43
IPV6CTL_MCAST_PMTU = 44
IPV6CTL_NEIGHBORGCTHRESH = 45
IPV6CTL_MAXDYNROUTES = 48
IPV6CTL_DAD_PENDING = 49
IPV6CTL_MTUDISCTIMEOUT = 50
IPV6CTL_IFQUEUE = 51
IPV6CTL_MRTMIF = 52
IPV6CTL_MRTMFC = 53
IPV6CTL_MAXID = 54
def in_nullhost(x): return ((x).s_addr == INADDR_ANY)




"""Make tests/ into a package. This allows us to "import tests" and
have tests.all_tests be a TestSuite representing all test cases
from all test_*.py files in tests/."""
# Author: Collin Winter

import os
import os.path
import unittest
import types

from . import support

all_tests = unittest.TestSuite()

tests_dir = os.path.join(os.path.dirname(__file__), '..', 'tests')
tests = [t[0:-3] for t in os.listdir(tests_dir)
                        if t.startswith('test_') and t.endswith('.py')]

loader = unittest.TestLoader()

for t in tests:
    __import__("",globals(),locals(),[t],level=1)
    mod = globals()[t]
    all_tests.addTests(loader.loadTestsFromModule(mod))



""" Python Character Mapping Codec generated from 'PTCP154.txt' with gencodec.py.

Written by Marc-Andre Lemburg (mal@lemburg.com).

(c) Copyright CNRI, All Rights Reserved. NO WARRANTY.
(c) Copyright 2000 Guido van Rossum.

"""#"

import codecs

### Codec APIs

class Codec(codecs.Codec):

    def encode(self,input,errors='strict'):
        return codecs.charmap_encode(input,errors,encoding_map)

    def decode(self,input,errors='strict'):
        return codecs.charmap_decode(input,errors,decoding_map)

class IncrementalEncoder(codecs.IncrementalEncoder):
    def encode(self, input, final=False):
        return codecs.charmap_encode(input,self.errors,encoding_map)[0]

class IncrementalDecoder(codecs.IncrementalDecoder):
    def decode(self, input, final=False):
        return codecs.charmap_decode(input,self.errors,decoding_map)[0]

class StreamWriter(Codec,codecs.StreamWriter):
    pass

class StreamReader(Codec,codecs.StreamReader):
    pass

### encodings module API

def getregentry():
    return codecs.CodecInfo(
        name='ptcp154',
        encode=Codec().encode,
        decode=Codec().decode,
        incrementalencoder=IncrementalEncoder,
        incrementaldecoder=IncrementalDecoder,
        streamreader=StreamReader,
        streamwriter=StreamWriter,
    )

### Decoding Map

decoding_map = codecs.make_identity_dict(range(256))
decoding_map.update({
        0x0080: 0x0496, #        CYRILLIC CAPITAL LETTER ZHE WITH DESCENDER
        0x0081: 0x0492, #        CYRILLIC CAPITAL LETTER GHE WITH STROKE
        0x0082: 0x04ee, #        CYRILLIC CAPITAL LETTER U WITH MACRON
        0x0083: 0x0493, #        CYRILLIC SMALL LETTER GHE WITH STROKE
        0x0084: 0x201e, #        DOUBLE LOW-9 QUOTATION MARK
        0x0085: 0x2026, #        HORIZONTAL ELLIPSIS
        0x0086: 0x04b6, #        CYRILLIC CAPITAL LETTER CHE WITH DESCENDER
        0x0087: 0x04ae, #        CYRILLIC CAPITAL LETTER STRAIGHT U
        0x0088: 0x04b2, #        CYRILLIC CAPITAL LETTER HA WITH DESCENDER
        0x0089: 0x04af, #        CYRILLIC SMALL LETTER STRAIGHT U
        0x008a: 0x04a0, #        CYRILLIC CAPITAL LETTER BASHKIR KA
        0x008b: 0x04e2, #        CYRILLIC CAPITAL LETTER I WITH MACRON
        0x008c: 0x04a2, #        CYRILLIC CAPITAL LETTER EN WITH DESCENDER
        0x008d: 0x049a, #        CYRILLIC CAPITAL LETTER KA WITH DESCENDER
        0x008e: 0x04ba, #        CYRILLIC CAPITAL LETTER SHHA
        0x008f: 0x04b8, #        CYRILLIC CAPITAL LETTER CHE WITH VERTICAL STROKE
        0x0090: 0x0497, #        CYRILLIC SMALL LETTER ZHE WITH DESCENDER
        0x0091: 0x2018, #        LEFT SINGLE QUOTATION MARK
        0x0092: 0x2019, #        RIGHT SINGLE QUOTATION MARK
        0x0093: 0x201c, #        LEFT DOUBLE QUOTATION MARK
        0x0094: 0x201d, #        RIGHT DOUBLE QUOTATION MARK
        0x0095: 0x2022, #        BULLET
        0x0096: 0x2013, #        EN DASH
        0x0097: 0x2014, #        EM DASH
        0x0098: 0x04b3, #        CYRILLIC SMALL LETTER HA WITH DESCENDER
        0x0099: 0x04b7, #        CYRILLIC SMALL LETTER CHE WITH DESCENDER
        0x009a: 0x04a1, #        CYRILLIC SMALL LETTER BASHKIR KA
        0x009b: 0x04e3, #        CYRILLIC SMALL LETTER I WITH MACRON
        0x009c: 0x04a3, #        CYRILLIC SMALL LETTER EN WITH DESCENDER
        0x009d: 0x049b, #        CYRILLIC SMALL LETTER KA WITH DESCENDER
        0x009e: 0x04bb, #        CYRILLIC SMALL LETTER SHHA
        0x009f: 0x04b9, #        CYRILLIC SMALL LETTER CHE WITH VERTICAL STROKE
        0x00a1: 0x040e, #        CYRILLIC CAPITAL LETTER SHORT U (Byelorussian)
        0x00a2: 0x045e, #        CYRILLIC SMALL LETTER SHORT U (Byelorussian)
        0x00a3: 0x0408, #        CYRILLIC CAPITAL LETTER JE
        0x00a4: 0x04e8, #        CYRILLIC CAPITAL LETTER BARRED O
        0x00a5: 0x0498, #        CYRILLIC CAPITAL LETTER ZE WITH DESCENDER
        0x00a6: 0x04b0, #        CYRILLIC CAPITAL LETTER STRAIGHT U WITH STROKE
        0x00a8: 0x0401, #        CYRILLIC CAPITAL LETTER IO
        0x00aa: 0x04d8, #        CYRILLIC CAPITAL LETTER SCHWA
        0x00ad: 0x04ef, #        CYRILLIC SMALL LETTER U WITH MACRON
        0x00af: 0x049c, #        CYRILLIC CAPITAL LETTER KA WITH VERTICAL STROKE
        0x00b1: 0x04b1, #        CYRILLIC SMALL LETTER STRAIGHT U WITH STROKE
        0x00b2: 0x0406, #        CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I
        0x00b3: 0x0456, #        CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
        0x00b4: 0x0499, #        CYRILLIC SMALL LETTER ZE WITH DESCENDER
        0x00b5: 0x04e9, #        CYRILLIC SMALL LETTER BARRED O
        0x00b8: 0x0451, #        CYRILLIC SMALL LETTER IO
        0x00b9: 0x2116, #        NUMERO SIGN
        0x00ba: 0x04d9, #        CYRILLIC SMALL LETTER SCHWA
        0x00bc: 0x0458, #        CYRILLIC SMALL LETTER JE
        0x00bd: 0x04aa, #        CYRILLIC CAPITAL LETTER ES WITH DESCENDER
        0x00be: 0x04ab, #        CYRILLIC SMALL LETTER ES WITH DESCENDER
        0x00bf: 0x049d, #        CYRILLIC SMALL LETTER KA WITH VERTICAL STROKE
        0x00c0: 0x0410, #        CYRILLIC CAPITAL LETTER A
        0x00c1: 0x0411, #        CYRILLIC CAPITAL LETTER BE
        0x00c2: 0x0412, #        CYRILLIC CAPITAL LETTER VE
        0x00c3: 0x0413, #        CYRILLIC CAPITAL LETTER GHE
        0x00c4: 0x0414, #        CYRILLIC CAPITAL LETTER DE
        0x00c5: 0x0415, #        CYRILLIC CAPITAL LETTER IE
        0x00c6: 0x0416, #        CYRILLIC CAPITAL LETTER ZHE
        0x00c7: 0x0417, #        CYRILLIC CAPITAL LETTER ZE
        0x00c8: 0x0418, #        CYRILLIC CAPITAL LETTER I
        0x00c9: 0x0419, #        CYRILLIC CAPITAL LETTER SHORT I
        0x00ca: 0x041a, #        CYRILLIC CAPITAL LETTER KA
        0x00cb: 0x041b, #        CYRILLIC CAPITAL LETTER EL
        0x00cc: 0x041c, #        CYRILLIC CAPITAL LETTER EM
        0x00cd: 0x041d, #        CYRILLIC CAPITAL LETTER EN
        0x00ce: 0x041e, #        CYRILLIC CAPITAL LETTER O
        0x00cf: 0x041f, #        CYRILLIC CAPITAL LETTER PE
        0x00d0: 0x0420, #        CYRILLIC CAPITAL LETTER ER
        0x00d1: 0x0421, #        CYRILLIC CAPITAL LETTER ES
        0x00d2: 0x0422, #        CYRILLIC CAPITAL LETTER TE
        0x00d3: 0x0423, #        CYRILLIC CAPITAL LETTER U
        0x00d4: 0x0424, #        CYRILLIC CAPITAL LETTER EF
        0x00d5: 0x0425, #        CYRILLIC CAPITAL LETTER HA
        0x00d6: 0x0426, #        CYRILLIC CAPITAL LETTER TSE
        0x00d7: 0x0427, #        CYRILLIC CAPITAL LETTER CHE
        0x00d8: 0x0428, #        CYRILLIC CAPITAL LETTER SHA
        0x00d9: 0x0429, #        CYRILLIC CAPITAL LETTER SHCHA
        0x00da: 0x042a, #        CYRILLIC CAPITAL LETTER HARD SIGN
        0x00db: 0x042b, #        CYRILLIC CAPITAL LETTER YERU
        0x00dc: 0x042c, #        CYRILLIC CAPITAL LETTER SOFT SIGN
        0x00dd: 0x042d, #        CYRILLIC CAPITAL LETTER E
        0x00de: 0x042e, #        CYRILLIC CAPITAL LETTER YU
        0x00df: 0x042f, #        CYRILLIC CAPITAL LETTER YA
        0x00e0: 0x0430, #        CYRILLIC SMALL LETTER A
        0x00e1: 0x0431, #        CYRILLIC SMALL LETTER BE
        0x00e2: 0x0432, #        CYRILLIC SMALL LETTER VE
        0x00e3: 0x0433, #        CYRILLIC SMALL LETTER GHE
        0x00e4: 0x0434, #        CYRILLIC SMALL LETTER DE
        0x00e5: 0x0435, #        CYRILLIC SMALL LETTER IE
        0x00e6: 0x0436, #        CYRILLIC SMALL LETTER ZHE
        0x00e7: 0x0437, #        CYRILLIC SMALL LETTER ZE
        0x00e8: 0x0438, #        CYRILLIC SMALL LETTER I
        0x00e9: 0x0439, #        CYRILLIC SMALL LETTER SHORT I
        0x00ea: 0x043a, #        CYRILLIC SMALL LETTER KA
        0x00eb: 0x043b, #        CYRILLIC SMALL LETTER EL
        0x00ec: 0x043c, #        CYRILLIC SMALL LETTER EM
        0x00ed: 0x043d, #        CYRILLIC SMALL LETTER EN
        0x00ee: 0x043e, #        CYRILLIC SMALL LETTER O
        0x00ef: 0x043f, #        CYRILLIC SMALL LETTER PE
        0x00f0: 0x0440, #        CYRILLIC SMALL LETTER ER
        0x00f1: 0x0441, #        CYRILLIC SMALL LETTER ES
        0x00f2: 0x0442, #        CYRILLIC SMALL LETTER TE
        0x00f3: 0x0443, #        CYRILLIC SMALL LETTER U
        0x00f4: 0x0444, #        CYRILLIC SMALL LETTER EF
        0x00f5: 0x0445, #        CYRILLIC SMALL LETTER HA
        0x00f6: 0x0446, #        CYRILLIC SMALL LETTER TSE
        0x00f7: 0x0447, #        CYRILLIC SMALL LETTER CHE
        0x00f8: 0x0448, #        CYRILLIC SMALL LETTER SHA
        0x00f9: 0x0449, #        CYRILLIC SMALL LETTER SHCHA
        0x00fa: 0x044a, #        CYRILLIC SMALL LETTER HARD SIGN
        0x00fb: 0x044b, #        CYRILLIC SMALL LETTER YERU
        0x00fc: 0x044c, #        CYRILLIC SMALL LETTER SOFT SIGN
        0x00fd: 0x044d, #        CYRILLIC SMALL LETTER E
        0x00fe: 0x044e, #        CYRILLIC SMALL LETTER YU
        0x00ff: 0x044f, #        CYRILLIC SMALL LETTER YA
})

### Encoding Map

encoding_map = codecs.make_encoding_map(decoding_map)



# Copyright (C) 2002-2004 Python Software Foundation
#
# A torture test of the email package.  This should not be run as part of the
# standard Python test suite since it requires several meg of email messages
# collected in the wild.  These source messages are not checked into the
# Python distro, but are available as part of the standalone email package at
# http://sf.net/projects/mimelib

import sys
import os
import unittest
from cStringIO import StringIO
from types import ListType

from email.test.test_email import TestEmailBase
from test.test_support import TestSkipped, run_unittest

import email
from email import __file__ as testfile
from email.iterators import _structure

def openfile(filename):
    from os.path import join, dirname, abspath
    path = abspath(join(dirname(testfile), os.pardir, 'moredata', filename))
    return open(path, 'r')

# Prevent this test from running in the Python distro
try:
    openfile('crispin-torture.txt')
except IOError:
    raise TestSkipped



class TortureBase(TestEmailBase):
    def _msgobj(self, filename):
        fp = openfile(filename)
        try:
            msg = email.message_from_file(fp)
        finally:
            fp.close()
        return msg



class TestCrispinTorture(TortureBase):
    # Mark Crispin's torture test from the SquirrelMail project
    def test_mondo_message(self):
        eq = self.assertEqual
        neq = self.ndiffAssertEqual
        msg = self._msgobj('crispin-torture.txt')
        payload = msg.get_payload()
        eq(type(payload), ListType)
        eq(len(payload), 12)
        eq(msg.preamble, None)
        eq(msg.epilogue, '\n')
        # Probably the best way to verify the message is parsed correctly is to
        # dump its structure and compare it against the known structure.
        fp = StringIO()
        _structure(msg, fp=fp)
        neq(fp.getvalue(), """\
multipart/mixed
    text/plain
    message/rfc822
        multipart/alternative
            text/plain
            multipart/mixed
                text/richtext
            application/andrew-inset
    message/rfc822
        audio/basic
    audio/basic
    image/pbm
    message/rfc822
        multipart/mixed
            multipart/mixed
                text/plain
                audio/x-sun
            multipart/mixed
                image/gif
                image/gif
                application/x-be2
                application/atomicmail
            audio/x-sun
    message/rfc822
        multipart/mixed
            text/plain
            image/pgm
            text/plain
    message/rfc822
        multipart/mixed
            text/plain
            image/pbm
    message/rfc822
        application/postscript
    image/gif
    message/rfc822
        multipart/mixed
            audio/basic
            audio/basic
    message/rfc822
        multipart/mixed
            application/postscript
            text/plain
            message/rfc822
                multipart/mixed
                    text/plain
                    multipart/parallel
                        image/gif
                        audio/basic
                    application/atomicmail
                    message/rfc822
                        audio/x-sun
""")


def _testclasses():
    mod = sys.modules[__name__]
    return [getattr(mod, name) for name in dir(mod) if name.startswith('Test')]


def suite():
    suite = unittest.TestSuite()
    for testclass in _testclasses():
        suite.addTest(unittest.makeSuite(testclass))
    return suite


def test_main():
    for testclass in _testclasses():
        run_unittest(testclass)



if __name__ == '__main__':
    unittest.main(defaultTest='suite')
